Module monitoring — Inmanta 2017.2.1 documentation

# Module monitoring

> - License: Apache 2.0
> - Version: 0.2
> - Author: Inmanta <code@inmanta.com>
> - Upstream project: https://github.com/inmanta/monitoring.git

## Entities

entity `monitoring::Aggregator`

  Parents: `std::Entity`

  A generic aggregator

  relation std::Host `host` [1]

    other end: `std::Host.aggregators [0:*]`

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `monitoring::EventAggregator`

  Parents: `monitoring::Aggregator`

  Aggregate events

  relation monitoring::HostTransport `event_transport` [0:*]

    other end: `monitoring::HostTransport.event_aggregators [0:1]`

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `monitoring::EventSource`

  Parents: `monitoring::Source`

  A source of events

entity `monitoring::HostTransport`

  Parents: `std::Entity`

  A component on a host that transports metrics, logs and events to somewhere. That can be over the network or to a file.

  relation monitoring::MetricAggregator `metric_aggregators` [0:1]

    other end: `monitoring::MetricAggregator.metric_transport [0:*]`

  relation monitoring::QueryAggregator `query_aggregators` [1]

    other end: `monitoring::QueryAggregator.query_transport [0:*]`

  relation std::Host `host` [1]

    other end: `std::Host.monitoring_transport [0:*]`

  relation monitoring::LogAggregator `log_aggregators` [0:1]

    other end: `monitoring::LogAggregator.log_transport [0:*]`

  relation monitoring::EventAggregator `event_aggregators` [0:1]

    other end: `monitoring::EventAggregator.event_transport [0:*]`

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `monitoring::JmxSource`

  Parents: `monitoring::LogSource`, `monitoring::MetricSource`, `monitoring::EventSource`

  Collect monitoring data from JMX

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `monitoring::JournaldTail`

  Parents: `monitoring::LogSource`

  Tail the output of journald and collect messages

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `monitoring::LogAggregator`

  Parents: `monitoring::Aggregator`

  Aggregate logs

  relation monitoring::HostTransport `log_transport` [0:*]

    other end: `monitoring::HostTransport.log_aggregators [0:1]`

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `monitoring::LogSource`

  Parents: `monitoring::Source`

  A source of log data

entity `monitoring::LogTail`

  Parents: `monitoring::LogSource`

  Put a tail on a log file and collect the log message

  attribute string `path`

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `monitoring::MetricAggregator`

  Parents: `monitoring::Aggregator`

  Aggregate metrics

  relation monitoring::HostTransport `metric_transport` [0:*]

    other end: `monitoring::HostTransport.metric_aggregators [0:1]`

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `monitoring::MetricCollector`

  Parents: `monitoring::MetricSource`

  Enable a sensor collect on a host

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `monitoring::MetricSource`

  Parents: `monitoring::Source`

  A source of metric data

entity `monitoring::QueryAggregator`

  Parents: `monitoring::Aggregator`

  The query interface

  relation monitoring::HostTransport `query_transport` [0:*]

    other end: `monitoring::HostTransport.query_aggregators [1]`

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `monitoring::Source`

  Parents: `std::Entity`

  A source of monitoring data

  relation std::Host `host` [1]

    other end: `std::Host.monitoring_source [0:*]`

  relation monitoring::Tag `tags` [0:*]

    other end: `monitoring::Tag.base [1]`

entity `monitoring::Tag`

  Parents: `std::Entity`

  A tag on a data source for monitoring tools

  attribute string `name`

    The name of the tag

  relation monitoring::Source `base` [1]

    other end: `monitoring::Source.tags [0:*]`

  The following implements statements select implementations for this entity:

  > - `std::none`